@@ -14,7 +14,6 @@ else:  # pragma: no cover (py38+)
 
 from .base import BaseCracker
 from ..magneto.session import Session, AsyncSession
-from ..magneto.response import Response
 
 class AkamaiV2Cracker(BaseCracker):
     
@@ -70,11 +69,11 @@ class AkamaiV2Cracker(BaseCracker):
 
 async def async_crack_akamai_v3(
     user_token: str, requests_args: Dict[str, str], 
-    other_requests: Optional[callable] = None,
+    other_requests: Optional[callable] = None, parse_index: Optional[str] = None, accept_language: Optional[str] = None,
     internal_host: bool = True, branch: Optional[str] = None,
     developer_id: Optional[str] = None, auth: bool = False,
     session: Optional[AsyncSession] = None, cookies: Dict[str, str] = {}, proxy: Optional[str] = None,
-    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http2_only: bool = False,
+    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http_version: Optional[Literal["http1", "http2"]] = None,
     user_agent: Union[str, Tuple[int, Literal["windows", "macos"], Literal["chrome", "edge"]]] = None,
     ipinfo: Dict[str, str] = {}, extra: Dict[str, str] = {},
     debug: bool = False
@@ -91,7 +90,7 @@ async def async_crack_akamai_v3(
             timeout=timeout, 
             allow_redirects=allow_redirects, 
             verify=verify, 
-            http2_only=http2_only
+            http_version=http_version
         )
         if not ipinfo:
             await session.update_ipinfo()
@@ -184,21 +183,24 @@ async def async_crack_akamai_v3(
             else:
                 raise Warning(f'akamai bm_sc 验证失败, id: {nocaptcha_resp["id"]}, err: {nocaptcha_resp["msg"]}')
         
+        if parse_index:
+            await parse_index(response, extra)
+        
         html = await response.async_text()
         
-        api = requests_args.get("api")
-        if not api:
-            try:
-                apis = re.findall("type=\"text\/javascript\"  src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"\>\<\/script\>", html)
-                if not apis:
-                    apis = re.findall("nonce=\"[a-f0-9]{32}\" src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"\>\<\/script\>", html)
-                if not apis:
-                    raise Warning('api 查找失败: ' + html)
-                api = apis[0]
-                if not api.startswith("http"):
-                    api = origin + api
-            except:
-                raise Warning('api 查找失败: ' + html)
+    api = requests_args.get("api")
+    if not api:
+        try:
+            apis = re.findall(r"type=\"text\/javascript\"[ ]{1,2}src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"(?: defer){0,1}\>\<\/script\>", html)
+            if not apis:
+                apis = re.findall(r"nonce=\"[a-f0-9]{32}\"[ ]{1,2}src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"(?: defer){0,1}\>\<\/script\>", html)
+            if not apis:
+                raise Warning('api 查找失败')
+            api = apis[0]
+            if not api.startswith("http"):
+                api = requests_args.get("api_host", origin) + api
+        except:
+            raise Warning('api 查找失败')
         
         headers = [
             f"sec-ch-ua-platform: {session.client_hints['sec-ch-ua-platform']}",
@@ -265,16 +267,16 @@ async def async_crack_akamai_v3(
                 
                 origin = "/".join(iframe_src.split("/")[0:3])
                 try:
-                    apis = re.findall("type=\"text\/javascript\"  src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"\>\<\/script\>", html)
+                    apis = re.findall(r"type=\"text\/javascript\"[ ]{1,2}src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"(?: defer){0,1}\>\<\/script\>", html)
                     if not apis:
-                        apis = re.findall("nonce=\"[a-f0-9]{32}\" src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"\>\<\/script\>", html)
+                        apis = re.findall(r"nonce=\"[a-f0-9]{32}\"[ ]{1,2}src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"(?: defer){0,1}\>\<\/script\>", html)
                     if not apis:
-                        raise Exception('iframe api 查找失败: ' + html)
+                        raise Warning('api 查找失败')
                     api = apis[0]
                     if not api.startswith("http"):
-                        api = origin + api
+                        api = requests_args.get("api_host", origin) + api
                 except:
-                    raise Exception('api 查找失败:' + html)
+                    raise Warning('api 查找失败')
 
                 headers = [
                     f"sec-ch-ua-platform: {session.client_hints['sec-ch-ua-platform']}",
@@ -346,11 +348,11 @@ async def async_crack_akamai_v3(
 
 def crack_akamai_v3(
     user_token: str, requests_args: Dict[str, str],
-    other_requests: Optional[callable] = None,
+    other_requests: Optional[callable] = None, parse_index: Optional[callable] = None,
     internal_host: bool = True, branch: Optional[str] = None,
     developer_id: Optional[str] = None, auth: bool = False,
     session: Optional[Session] = None, cookies: Dict[str, str] = {}, proxy: Optional[str] = None,
-    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http2_only: bool = False,
+    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http_version: Optional[Literal["http1", "http2"]] = None,
     user_agent: Union[str, Tuple[int, Literal["windows", "macos"], Literal["chrome", "edge"]]] = None,
     ipinfo: Dict[str, str] = {}, extra: Dict[str, str] = {},
     debug: bool = False
@@ -367,7 +369,7 @@ def crack_akamai_v3(
             timeout=timeout, 
             allow_redirects=allow_redirects, 
             verify=verify, 
-            http2_only=http2_only
+            http_version=http_version
         )
         if not ipinfo:
             session.update_ipinfo()
@@ -460,19 +462,23 @@ def crack_akamai_v3(
         else:
             raise Warning(f'akamai bm_sc 验证失败, id: {nocaptcha_resp["id"]}, err: {nocaptcha_resp["msg"]}')
     
+    if parse_index:
+        parse_index(response, extra)
+    
+    html = response.text
     api = requests_args.get("api")
     if not api:
         try:
-            apis = re.findall("type=\"text\/javascript\"  src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"\>\<\/script\>", response.text)
+            apis = re.findall(r"type=\"text\/javascript\"[ ]{1,2}src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"(?: defer){0,1}\>\<\/script\>", html)
             if not apis:
-                apis = re.findall("nonce=\"[a-f0-9]{32}\" src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"\>\<\/script\>", response.text)
+                apis = re.findall(r"nonce=\"[a-f0-9]{32}\"[ ]{1,2}src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"(?: defer){0,1}\>\<\/script\>", html)
             if not apis:
-                raise Warning('api 查找失败: ' + response.text)
+                raise Warning('api 查找失败')
             api = apis[0]
             if not api.startswith("http"):
-                api = origin + api
+                api = requests_args.get("api_host", origin) + api
         except:
-            raise Warning('api 查找失败: ' + response.text)
+            raise Warning('api 查找失败')
     
     headers = [
         f"sec-ch-ua-platform: {session.client_hints['sec-ch-ua-platform']}",
@@ -539,17 +545,18 @@ def crack_akamai_v3(
             response = session.get(iframe_src, headers=headers)
             
             origin = "/".join(iframe_src.split("/")[0:3])
+            html = response.text
             try:
-                apis = re.findall("type=\"text\/javascript\"  src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"\>\<\/script\>", response.text)
+                apis = re.findall(r"type=\"text\/javascript\"[ ]{1,2}src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"(?: defer){0,1}\>\<\/script\>", html)
                 if not apis:
-                    apis = re.findall("nonce=\"[a-f0-9]{32}\" src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"\>\<\/script\>", response.text)
+                    apis = re.findall(r"nonce=\"[a-f0-9]{32}\"[ ]{1,2}src\=\"((?:\/[A-Za-z0-9\-\_\+]*?)+)\"(?: defer){0,1}\>\<\/script\>", html)
                 if not apis:
-                    raise Exception('iframe api 查找失败: ' + response.text)
+                    raise Warning('api 查找失败')
                 api = apis[0]
                 if not api.startswith("http"):
-                    api = origin + api
+                    api = requests_args.get("api_host", origin) + api
             except:
-                raise Exception('api 查找失败:' + response.text)
+                raise Warning('api 查找失败')
 
             headers = [
                 f"sec-ch-ua-platform: {session.client_hints['sec-ch-ua-platform']}",
