@@ -1,9 +1,7 @@
-import warnings
+# -*- coding: UTF-8 -*-
 
 from .base import BaseCracker
 
-warnings.filterwarnings('ignore')
-
 
 class CloudFlareCracker(BaseCracker):
     
