@@ -1,7 +1,6 @@
-from .base import BaseCracker
+# -*- coding: UTF-8 -*-
 
-import warnings
-warnings.filterwarnings('ignore')
+from .base import BaseCracker
 
 
 class DiscordCracker(BaseCracker):
