@@ -45,7 +45,7 @@ async def async_crack_kasada(
     internal_host: bool = True, branch: Optional[str] = None,
     developer_id: Optional[str] = None, auth: bool = False,
     session: Optional[AsyncSession] = None, cookies: Dict[str, str] = {},
-    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http2_only: bool = False,
+    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http_version: Optional[Literal["http1", "http2"]] = None,
     user_agent: Union[str, Tuple[int, Literal["windows", "macos"], Literal["chrome", "edge"]]] = None,
     ipinfo: Dict[str, str] = {}, extra: Dict[str, str] = {}, debug: bool = False
 ) -> Tuple[AsyncSession, Dict[str, Any], Dict[str, Any]]:
@@ -58,7 +58,7 @@ async def async_crack_kasada(
             timeout=timeout, 
             allow_redirects=allow_redirects, 
             verify=verify, 
-            http2_only=http2_only
+            http_version=http_version
         )
         if not ipinfo:
             await session.update_ipinfo()
@@ -230,7 +230,7 @@ def crack_kasada(
     internal_host: bool = True, branch: Optional[str] = None,
     developer_id: Optional[str] = None, auth: bool = False,
     session: Optional[Session] = None, cookies: Dict[str, str] = {},
-    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http2_only: bool = False,
+    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http_version: Optional[Literal["http1", "http2"]] = None,
     user_agent: Union[str, Tuple[int, Literal["windows", "macos"], Literal["chrome", "edge"]]] = None,
     ipinfo: Dict[str, str] = {}, extra: Dict[str, str] = {}, debug: bool = False
 ) -> Tuple[Session, Dict[str, Any], Dict[str, Any]]:
@@ -243,7 +243,7 @@ def crack_kasada(
             timeout=timeout, 
             allow_redirects=allow_redirects, 
             verify=verify, 
-            http2_only=http2_only
+            http_version=http_version
         )
         if not ipinfo:
             session.update_ipinfo()
